Index: /issm/trunk/src/c/objects/Loads/Icefront.cpp
===================================================================
--- /issm/trunk/src/c/objects/Loads/Icefront.cpp	(revision 3862)
+++ /issm/trunk/src/c/objects/Loads/Icefront.cpp	(revision 3863)
@@ -1349,8 +1349,37 @@
 }
 /*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
+void  Icefront::UpdateInputsFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
+void  Icefront::UpdateInputsFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
+void  Icefront::UpdateInputsFromVector(bool* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromConstant(double constant, int name) {{{1*/
+void  Icefront::UpdateInputsFromConstant(double constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
 /*FUNCTION Icefront::UpdateInputsFromConstant(int constant, int name) {{{1*/
-void Icefront::UpdateInputsFromConstant(int constant, int name){
-
-	/*Nothing updated for now*/
-}
-/*}}}*/
+void  Icefront::UpdateInputsFromConstant(int constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromConstant(bool constant, int name) {{{1*/
+void  Icefront::UpdateInputsFromConstant(bool constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Icefront::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type) {{{1*/
+void  Icefront::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
Index: /issm/trunk/src/c/objects/Loads/Icefront.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Icefront.h	(revision 3862)
+++ /issm/trunk/src/c/objects/Loads/Icefront.h	(revision 3863)
@@ -50,12 +50,12 @@
 		int   MarshallSize();
 		int   MyRank();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromConstant(int constant, int name);
-		void    UpdateInputsFromConstant(bool constant, int name){ISSMERROR("Not implemented yet!");}
+		void  UpdateInputsFromVector(double* vector, int name, int type);
+		void  UpdateInputsFromVector(int* vector, int name, int type);
+		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  UpdateInputsFromConstant(double constant, int name);
+		void  UpdateInputsFromConstant(int constant, int name);
+		void  UpdateInputsFromConstant(bool constant, int name);
 
-		void    UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){ISSMERROR("Not implemented yet!");}
+		void  UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type);
 
 
Index: /issm/trunk/src/c/objects/Materials/Matice.h
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matice.h	(revision 3862)
+++ /issm/trunk/src/c/objects/Materials/Matice.h	(revision 3863)
@@ -45,12 +45,11 @@
 		double GetB();
 		double GetN();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromConstant(int constant, int name);
-		void    UpdateInputsFromConstant(bool constant, int name){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){ISSMERROR("Not implemented yet!");}
-
+		void  UpdateInputsFromVector(double* vector, int name, int type);
+		void  UpdateInputsFromVector(int* vector, int name, int type);
+		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  UpdateInputsFromConstant(double constant, int name);
+		void  UpdateInputsFromConstant(int constant, int name);
+		void  UpdateInputsFromConstant(bool constant, int name);
+		void  UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type);
 
 };
Index: /issm/trunk/src/c/objects/Materials/Matpar.cpp
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matpar.cpp	(revision 3862)
+++ /issm/trunk/src/c/objects/Materials/Matpar.cpp	(revision 3863)
@@ -282,8 +282,37 @@
 }
 /*}}}1*/
-/*FUNCTION Matpar::UpdateInputsFromConstant(int constant, int name){{{1*/
-void Matpar::UpdateInputsFromConstant(int constant, int name){
-
-	/*Nothing updated for now*/
-}
-/*}}}1*/
+/*FUNCTION Matpar::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
+void   Matpar::UpdateInputsFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
+void   Matpar::UpdateInputsFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
+void   Matpar::UpdateInputsFromVector(bool* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromConstant(double constant, int name) {{{1*/
+void   Matpar::UpdateInputsFromConstant(double constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromConstant(int constant, int name) {{{1*/
+void   Matpar::UpdateInputsFromConstant(int constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromConstant(bool constant, int name) {{{1*/
+void   Matpar::UpdateInputsFromConstant(bool constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type) {{{1*/
+void   Matpar::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
Index: /issm/trunk/src/c/objects/Materials/Matpar.h
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matpar.h	(revision 3862)
+++ /issm/trunk/src/c/objects/Materials/Matpar.h	(revision 3863)
@@ -57,12 +57,11 @@
 		double GetMeltingPoint();
 		Object* copy();
-		void   UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void   UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void   UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void   UpdateInputsFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
+		void   UpdateInputsFromVector(double* vector, int name, int type);
+		void   UpdateInputsFromVector(int* vector, int name, int type);
+		void   UpdateInputsFromVector(bool* vector, int name, int type);
+		void   UpdateInputsFromConstant(double constant, int name);
 		void   UpdateInputsFromConstant(int constant, int name);
-		void   UpdateInputsFromConstant(bool constant, int name){ISSMERROR("Not implemented yet!");}
-
-		void   UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){ISSMERROR("Not implemented yet!");}
+		void   UpdateInputsFromConstant(bool constant, int name);
+		void   UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type);
 
 
Index: /issm/trunk/src/c/objects/Vertex.cpp
===================================================================
--- /issm/trunk/src/c/objects/Vertex.cpp	(revision 3862)
+++ /issm/trunk/src/c/objects/Vertex.cpp	(revision 3863)
@@ -182,9 +182,33 @@
 }
 /*}}}*/
-/*FUNCTION UpdateInputsFromConstant(int constant, int name){{{2*/
+
+/*FUNCTION Vertex::UpdateInputsFromVector(double* vector, int name, int type) {{{2*/
+void  Vertex::UpdateInputsFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::UpdateInputsFromVector(int* vector, int name, int type) {{{2*/
+void  Vertex::UpdateInputsFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::UpdateInputsFromVector(bool* vector, int name, int type) {{{2*/
+void  Vertex::UpdateInputsFromVector(bool* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::UpdateInputsFromConstant(double constant, int name) {{{2*/
+void  Vertex::UpdateInputsFromConstant(double constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::UpdateInputsFromConstant(int constant, int name) {{{2*/
 void  Vertex::UpdateInputsFromConstant(int constant, int name){
-
-	/*Nothing updated for now*/
-
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::UpdateInputsFromConstant(bool constant, int name) {{{2*/
+void  Vertex::UpdateInputsFromConstant(bool constant, int name){
+	/*Nothing updated yet*/
 }
 /*}}}*/
Index: /issm/trunk/src/c/objects/Vertex.h
===================================================================
--- /issm/trunk/src/c/objects/Vertex.h	(revision 3862)
+++ /issm/trunk/src/c/objects/Vertex.h	(revision 3863)
@@ -50,10 +50,10 @@
 		void  UpdateFromDakota(void* vinputs);
 		void  UpdatePosition(double* thickness,double* bed);
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
+		void  UpdateInputsFromVector(double* vector, int name, int type);
+		void  UpdateInputsFromVector(int* vector, int name, int type);
+		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  UpdateInputsFromConstant(double constant, int name);
 		void  UpdateInputsFromConstant(int constant, int name);
-		void  UpdateInputsFromConstant(bool constant, int name){ISSMERROR("Not implemented yet!");}
+		void  UpdateInputsFromConstant(bool constant, int name);
 
 		void  UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){ISSMERROR("Not implemented yet!");}

Index: /issm/trunk/src/c/objects/Materials/Matice.cpp
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matice.cpp	(revision 3862)
+++ /issm/trunk/src/c/objects/Materials/Matice.cpp	(revision 3863)
@@ -438,9 +438,37 @@
 }
 /*}}}*/
-/*FUNCTION Matice::UpdateInputsFromConstant(int constant, int name){{{1*/
+/*FUNCTION Matice::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
+void  Matice::UpdateInputsFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
+void  Matice::UpdateInputsFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
+void  Matice::UpdateInputsFromVector(bool* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromConstant(double constant, int name) {{{1*/
+void  Matice::UpdateInputsFromConstant(double constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromConstant(int constant, int name) {{{1*/
 void  Matice::UpdateInputsFromConstant(int constant, int name){
-
-	/*Nothing updated for now*/
-
-}
-/*}}}*/
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromConstant(bool constant, int name) {{{1*/
+void  Matice::UpdateInputsFromConstant(bool constant, int name){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type) {{{1*/
+void  Matice::UpdateInputsFromSolution(double* solution, int analysis_type, int sub_analysis_type){
+	/*Nothing updated yet*/
+}
+/*}}}*/